%  FEMB-Programs (Version: 1.0):  Finite Element Methods with B-Splines
%
% MAIN PROGRAMS
%
% bvp_2d.m: 2D Ritz-Galerkin approximation for  -div(p grad u) + q u = f 
% bvp_3d.m: 3D Ritz-Galerkin approximation for  -div(p grad u) + q u = f 
% elasticity_2d.m: 2D Ritz-Galerkin approximation for the Lame-Navier system
% elasticity_3d.m: 3D Ritz-Galerkin approximation for the Lame-Navier system
%
% DEMOS AND EXAMPLES 
%
% demo_bvp_2d.m: solves -Delta u = f with mixed boundary conditions 
% demo_bvp_3d.m: solves -Delta u + u = f with Neumann boundary conditions
% demo_elasticity_2d.m: deformation of a bridge-shaped domain under gravity
% demo_elasticity_3d.m:% deformation of a rotating solid of revolution
% demo_integrate_2d.m: statistics for a random 2d integrand 
% demo_integrate_3d.m: statistics for a random 3d integrand 
% demo_spline_2d.m: graph and grid of a bivariate random spline 
% demo_spline_3d.m: visualization of trivariate random spline
%
% example_BASIC.m: BASIC example - Delta u = f, Dirichlet boundary conditions 
% example_bvp_2d_convergence.m: convergence analysis for the Poisson problem 
% example_bvp_3d_convergence.m: convergence (increasing degree, fixed grid width) 
% example_bvp_3d_csg.m: exmple for a domain constructed with Boolean operations 
% example_elasticity_2d_disc.m: displacement of an excentric rotating steel disc
% example_elasticity_2d_tunnel.m: displacement of a tunnel-shaped structure 
% example_elasticity_3d_dome.m:% displacement of an concrete dome under gravity
%
% AUXILIARY FUNCTIONS
%
% set_par.m:  set defaults for algorithmic parameters 
% integrate_2d.m: parameters for numerical integration over 2d grid 
% integrate_3d.m: parameters for numerical integration over 3d grid 
% spline_2d.m: values of a spline on a regular grid in (0,1)^2
% spline_3d.m: values of a spline on a regular grid in (0,1)^3
%
% w_... : weight functions 
%
% 
% authors/copyright 2011: Klaus Hoellig and Joerg Hoerner
% 
% The programs are intended as a supplement to the SIAM book
% 
% Finite Element Methods with B-splines 
% (Frontiers in Applied Mathematics, 2003);
% 
% see the documentation for details and for explanations of the demos,
% examples, and main programs.
