function [U,wuXY,X,Y,R,e] = bvp_2d(p,q,f,wD,w,H,n,PAR) 
% [U,wuXY,X,Y,R,e] = bvp_2d(p,q,f,wD,w,H,n,PAR) 
%
% Ritz-Galerkin approximation for
%   -div(p grad u) + q u = f  
% with weighted b-splines
%   u ~ sum_k1,k2 U(k1,k2) w(x,y) b_k(x,y)
% on the domain D in (0,1)^2 with wD>0
%
% function [P,Px,Py] = p(x,y)
% function Q = q(x,y)
%   functions in the bilinear form 
% function F = f(x,y) 
%   force 
% function W = wD(x,y)
%   positive on the domain D, subset of (0,1)^2
% function [W,Wx,Wy] = w(x,y)
%   models essential homogeneous boundary conditions
% H
%   number of cells per coordinate direction, width 1/H
% n 
%   degree of the b-splines
% PAR
%   algorithmic parameters
% U(1:H+n,1:H+n)
%   coefficients of the solution
% wuXYZ(1:H*M,1:H*M)
%  grid values of the weighted spline, M=PAR.values
% X(1:H*M,1:H*M), Y(1:H*M,1:H*M)
%  uniform grid of (H*M)^2 points in (0,1)^2, M=PAR.values
% R(1:M*H,1:M*H)
%  residuum of the partial differential equation, M=PAR.values 
% e
%   relative error for the partial differential equation 
% -> see documentation for details 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

if PAR.info, fprintf('\nbvp_2d\n'); end

% integration, assembly, solution, evaluation, and visualization
int = integrate_2d(wD,H,PAR);
[G,F] = assemble_2d(p,q,f,w,H,n,int,PAR);
U = solve_2d(G,F,PAR);
[wuXY,X,Y,R,e] = evaluate_2d(p,q,f,wD,w,U,H,n,PAR);
if PAR.info > 1, visualize_2d(wD,wuXY,X,Y,H); end

