function [U,wuXYZ,X,Y,Z,R,e] = bvp_3d(p,q,f,wD,w,H,n,PAR) 
% [U,wuXYZ,X,Y,Z,R,e] = bvp_3d(p,q,f,wD,w,H,n,PAR) 
%
% Ritz-Galerkin approximation for 
%   -div(p grad u) + q u = f  
% with weighted b-splines
%   u ~ sum_k1,k2,k3 U(k1,k2,k3) w(x,y,z) b_k(x,y,z)
% on the domain in (0,1)^3 with wD>0
%
% function [P,Px,Py,Pz] = p(x,y,z)
% function Q = q(x,y,z)
%   functions in the bilinear form 
% function F = f(x,y,z)
%   force 
% function W = wD(x,y,z)
%   positive on domain D, subset of (0,1)^3
% function [W,Wx,Wy,Wz] = w(x,y,z)
%   models essential homogeneous boundary conditions
% H
%   number of cells per coordinate direction, width 1/H
% n 
%   degree of the b-splines
% PAR
%   algorithmic parameters
% U(1:H+n,1:H+n,1:H+n)
%   coefficients of the solution
% wuXYZ(1:H*M,1:H*M,1:H*M)
%  grid values of the weighted spline, M=PAR.values
% X(1:H*M,1:H*M,1:H*M), Y(1:H*M,1:H*M,1:H*M), Z(1:H*M,1:H*M,1:H*M)
%  uniform grid of (H*M)^3 points in (0,1)^3, M=PAR.values
% R(1:M*H,1:M*H,1:H*M)
%  residuum of the partial differential equation, M=PAR.values 
% e
%   relative error for the differential equation 
% -> see documentation for details

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

if PAR.info, fprintf('\nbvp_3d\n'); end

% integration, assembly, solution, evaluation, and visualization
int = integrate_3d(wD,H,PAR);
[G,F] = assemble_3d(p,q,f,w,H,n,int,PAR);
U = solve_3d(G,F,PAR);
[wuXYZ,X,Y,Z,R,e] = evaluate_3d(p,q,f,wD,w,U,H,n,PAR);
if PAR.info > 1, visualize_3d(wD,wuXYZ,X,Y,Z); end

