function demo_bvp_2d
% demo: program bvp_2d 
% solves -Delta u = f with mixed boundary conditions 
% domain: subset of the unit square (0,1)^2, defined by wD(x,y) > 0  
% Dirichlet boundary (must be nonempty): segment of x-axis
% Neumann boundary: remaining boundary portion 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_bvp_2d

fprintf('specify parameters or press <return> to use [defaults]\n\n')
fprintf('functions operate on and return arrays\n')
fprintf('use, e.g., @(x,y) 2*ones(size(x)), @(x,y) x.*y, ... instead of 2, x*y, ...,\n\n');

% user input
f = input('force f [@(x,y) 3*x-y]: ');
if isempty(f), f = @(x,y) 3*x-y; end

wD = input('weight function wD, defines domain in (0,1)^2 by wD(x,y)>0 [@(x,y) 1-x.^2-y.^2]: ');
if isempty(wD), wD = @(x,y) 1-x.^2-y.^2; end

H = input('number of cells per coordinate direction [10]: ');
if isempty(H), H = 10; end

n = input('degree (<6) [3]: ');
if isempty(n), n = 3; end

% pde
p = @p_exp;
q = @(x,y) x+2*y;

% essential boundary 
w  = @w_line; 

% algorithmic parameters (defaults)
PAR = set_par(H,n);PAR.values=15;

% finite element approximation and visualization
clf;
[U,wuXY,X,Y,R,e] = bvp_2d(p,q,f,wD,w,H,n,PAR); 

%%%%% LOCAL FUNCTIONS

function [P,Px,Py] = p_exp(x,y)
% coefficient of the bilinear form
P = exp(x.*y); 
Px = y.*P; Py = x.*P;

function [W,Wx,Wy,Wxx,Wxy,Wyy] = w_line(x,y) 
% weight function for the x-axis as essential boundary 
W = y; 
Wx = zeros(size(x)); Wy = ones(size(y));
Wxx = Wx; Wxy = Wx; Wyy = Wx;

