function demo_bvp_3d() 
% demo: program bvp_3d
% solves -Delta u + u = f with Neumann boundary conditions
% domain: subset of the unit cube (0,1)^3, defined by wD(x,y,z) > 0  

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_bvp_3d 
fprintf('specify parameters or press <return> to use [defaults]\n\n')
fprintf('functions operate on and return arrays\n')
fprintf('use, e.g., @(x,y,z) 2*ones(size(x)), @(x,y,z) y.*z, ... instead of 2, y*z, ...\n\n');

% user input
f = input('force f [@(x,y,z) exp(x+y+z)]: ');
if isempty(f), f = @(x,y,z) exp(x+y+z); end

wD = input('weight function wD, defines domain in (0,1)^3 by wD(x,y,z)>0 [@(x,y,z) (x-1/2).^2+(y-1/2).^2-1/9]: ');
if isempty(wD)
  wD = @(x,y,z) (x-1/2).^2+(y-1/2).^2-1/9;
end

H = input('number of cells per coordinate direction [10]: ');
if isempty(H), H = 10; end

n = input('degree (<6) [2]: ');
if isempty(n), n = 2; end

% pde
p = @p_poisson;
q = @(x,y,z) ones(size(x));

% essential boundary 
w = @w_one;

% algorithmic parameters (defaults)
PAR = set_par(H,n);

% finite element approximation and visualization
clf;
[U,wuXYZ,X,Y,Z,R,e] = bvp_3d(p,q,f,wD,w,H,n,PAR);

