function demo_elasticity_2d()
% demo: program elasticity_2d 
% solves the Navier-Lame system in two dimensions (plain strain model)
% deformation of a bridge-shaped domain under gravity

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_elasticity_2d
fprintf('specify parameters or press <return> to use [defaults]\n\n')

% user input
height = input('height of parabola (>0, <1) [0.7]: ');
if isempty(height), height = 0.7; end

width = input('width of parabola (>0, <1) [0.4]: ');
if isempty(width), width = 0.4; end

H = input('number of cells per coordinate direction [10]: ');
if isempty(H), H = 10; end

n = input('degree (<6) [3]: ');
if isempty(n), n = 3; end

% pde
model = 'strain';
E = 1; nu = 0.2; 
f = @f_gravity;

% domain and essential boundary 
wD = @(x,y) y/height+(x-1/2).^2/(width/2)^2-1;
w  = @w_line; 

% algorithmic parameters   
PAR = set_par(H,n); PAR.values=20;

% finite element approximation and visualization
clf;
[U,wuXY,X,Y,R,e] = elasticity_2d(model,E,nu,f,wD,w,H,n,PAR);

