function demo_elasticity_3d()
% demo: program elasticity_3d 
% solves the Navier-Lame system in three dimensions 
% deformation of a rotating solid of revolution, fixed at an inner cylinder 
% symmetry axis: (1/2,1/2,z), 0<= z <=1

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_elasticity_3d
fprintf('specify parameters or press <return> to use [defaults]\n\n')
fprintf('functions operate on and return arrays\n')
fprintf('use, e.g., @(z) ones(size(z))/3, @(z) 1/4+z.^2/5, ... instead of 1/3, 1/4+z2/5, ...\n\n');


% user input
profile = input('profile R(z), 0<=z<=1, (>0.2, <0.5) of solid [@(z) sqrt(1+z.^2)/3]: ');
if isempty(profile), profile = @(z) sqrt(1+z.^2)/3;,end

H = input('number of cells per coordinate direction [8]: ');
if isempty(H), H = 8; end

n = input('degree (<6) [1]: ');
if isempty(n), n = 1; end

% pde
E = 1; nu = 0.28; 
f = @(x,y,z) f_centrifugal(x-1/2,y-1/2,z);

% domain and essential boundary 
w  = @(x,y,z) w_cylinder(x-1/2,y-1/2,z,1/5); 
wD = @(x,y,z) -w(x,y,z).*(profile(z).^2-(x-1/2).^2-(y-1/2).^2);

% algorithmic parameters (defaults)
PAR = set_par(H,n);

% finite element approximation and visualization
clf;
[U,wuXYZ,X,Y,Z] = elasticity_3d(E,nu,f,wD,w,H,n,PAR);

