function demo_integrate_2d()
% demo: program integrate_2d 
% statistics for a random integrand 
% domain: unit square with a random circular hole

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_integrate_2d
fprintf('specify parameters or press <return> to use [defaults]\n\n')

% user input of grid and algorithmic parameters
H = input('number of cells per coordinate [6]: ');
if isempty(H), H = 6; end
PAR=set_par(H,2);

PAR.fit = input('order of interpolation for the weight function (<8) [3]: ');
if isempty(PAR.fit), PAR.fit = 3; end
 
PAR.gauss = input('minimal number of Gauss points per coordinate (<6) [3]: ');
if isempty(PAR.gauss), PAR.gauss = 3; end

PAR.steps = input('number of Gauss steps (<5) [2]: ');
if isempty(PAR.steps), PAR.steps = 2; end

% random weight function (unit square with circular hole)
r = 0.1+0.4*rand(1);
c = 1/2+(-1+2*rand(2,1))*(1/2-r);
wD = @(x,y) (x-c(1)).^2+(y-c(2)).^2-r*r;  

% random integrand (a*[x; y]) and exact integral s
a = rand(2,1); 
s = 0; 
for k=1:2
  s = s + a(k)*(1/2-c(k)*pi*r*r);
end

% run program
c_time = clock;
int = integrate_2d(wD,H,PAR);
c_time = etime(clock,c_time);

% numerical integration 
% subtract cell values from exact integral -> error
pts = 0;
for m1=1:H, for m2=1:H
  s = s-int.c{m1,m2}'*(int.p{m1,m2}*a);
  pts = pts+length(int.p{m1,m2}(:));
end, end

% statistics 
fprintf('\nstatistics\n')
fprintf(' global error for random linear integrand: %12.4e\n',abs(s))
fprintf(' cells: %10d\n',H^2)
fprintf(' points/cell (average): %5.0f\n',pts/H^2)
fprintf(' computing time (seconds): %8.3f\n\n',c_time)

% visualization
if PAR.info>1
  fprintf('visualization\n');fh=figure;
  fprintf('press <return> repeatedly to cycle through cells\n');

  % auxiliary variables
  [x,y] = ndgrid(linspace(0,1)');
  z = wD(x,y); 
  Xg = [[0:H]/H, zeros(1,H+1); [0:H]/H, ones(1,H+1)];
  Yg = [zeros(1,H+1), [0:H]/H; ones(1,H+1), [0:H]/H];
  xs = [-1 0 0 -1 -1]/H; ys = [-1 -1 0 0 -1]/H;
  % loop over grid cells
  for m1=1:H, for m2=1:H
    clf 
    % plot domain and current cell
    subplot(1,2,1), hold on
    contour(x,y,z,[0 0])
    fill(m1/H+xs, m2/H+ys,'b')
    plot(Xg,Yg)
    axis([0 1 0 1]), axis equal 
    title('domain with grid cells')
    % plot Gauss point on current cell
    subplot(1,2,2), hold on
    xm = (m1-1+x)/H; ym = (m2-1+y)/H; zm = wD(xm,ym);
    contour(xm,ym,zm,[0 0])
    ind = find(int.c{m1,m2}>0);
    plot(int.p{m1,m2}(ind,1),int.p{m1,m2}(ind,2),'+')
    plot(m1/H+xs,m2/H+ys)
    axis([m1-1 m1 m2-1 m2]/H), axis equal, 
    title('distribution of Gauss points')
    pause
  end, end
close(fh);
end 
