function demo_integrate_3d()
% demo: program integrate_3d 
% statistics for a random integrand 
% domain: unit cube with a random spherical hole

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_integrate_3d
fprintf('specify parameters or press <return> to use [defaults]\n\n')

% user input of grid and algorithmic parameters 
H = input('number of cells per coordinate [4]: ');
if isempty(H), H = 4; end
PAR=set_par(H,2);

PAR.fit = input('order of interpolation for the weight function (<8) [3]: ');
if isempty(PAR.fit), PAR.fit = 3; end
 
PAR.gauss = input('minimal number of Gauss points per coordinate (<6) [2]: ');
if isempty(PAR.gauss), PAR.gauss = 2; end

PAR.steps = input('number of Gauss steps (<5) [2]: ');
if isempty(PAR.steps), PAR.steps = 2; end

% random weight function (unit cube with spherical hole)
r = 0.1+0.4*rand(1);
c = 1/2+(-1+2*rand(3,1))*(1/2-r);
wD = @(x,y,z) (x-c(1)).^2+(y-c(2)).^2+(z-c(3)).^2-r*r;  

% random integrand (a*[x; y; z]) and exact integral s
a = rand(3,1); 
s = 0; 
for k=1:3
  s = s + a(k)*(1/2-c(k)*(4*pi/3)*r*r*r);
end

% call program 
c_time = clock;
int = integrate_3d(wD,H,PAR);
c_time = etime(clock,c_time);
 
% numerical integration 
% subtract cell values from exact integral -> error
pts = 0;
for m1=1:H, for m2=1:H, for m3=1:H
  s = s-int.c{m1,m2,m3}'*(int.p{m1,m2,m3}*a);
  pts = pts+length(int.c{m1,m2,m2}(:));
end, end, end

% statistics 
fprintf('\nstatistics\n')
fprintf(' global error for test data: %12.4e\n',abs(s))
fprintf(' cells: %10d\n',H^3)
fprintf(' points/cell (average): %5.0f\n',pts/H^3)
fprintf(' computing time (seconds): %8.3f\n\n',c_time)

% visualization
if PAR.info>1
  fprintf('visualization\n');fh=figure;
  fprintf('press <return> repeatedly to cycle through boundary cells\n\n');
  
  % auxiliary variables
  [x,y,z] = ndgrid([-32:0]/32);
  for m1=1:H, for m2=1:H, for m3=1:H
    ptsm = length(int.c{m1,m2,m3});
    if ptsm>pts/H^3
      fprintf(' cell (%4d %4d %4d),     points %4d\n',[m1,m2,m3,ptsm])
      xm = (x+m1)/H; ym = (y+m2)/H; zm = (z+m3)/H;
      clf, hold on
      p = patch(isosurface(xm,ym,zm,wD(xm,ym,zm),0));
      set(p,'FaceColor','yellow','EdgeColor','none')
      ind = find(int.c{m1,m2,m3}>0);
      plot3(int.p{m1,m2,m3}(ind,1),int.p{m1,m2,m3}(ind,2),int.p{m1,m2,m3}(ind,3),'+')
      axis([(m1-1)/H, m1/H, (m2-1)/H, m2/H, (m3-1)/H, m3/H])
      view(3), box on, grid on 
      title('distribution of Gauss points for boundary cells')
      pause 
    end
  end, end, end
close(fh);
end
