function demo_spline_2d()
% demo: program spline_2d
% graph and grid of a bivariate random spline as well as selected B-splines 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

help demo_spline_2d
fprintf('specify parameters or press <return> to use [defaults]\n\n')

% user input
H = input('number of cells per dimension [10]: ');
if isempty(H), H = 10; end

n = input('degree [3]: ');
if isempty(n), n = 3; end

% evaluate spline with random coefficents
U = rand(H+n,H+n); M=4;

[uXY,X,Y] = spline_2d(U,H,n,M);

% plot 
clf, hold on
surf(X,Y,uXY,'FaceAlpha',0.6)
colormap winter
axis([[-n H+n -n H+n]/H min([U(:);0]) max([U(:);0])]);
axis off
view(3)
shading interp
title('graph of random spline and selected B-splines')

% plot grid
marks = [0:H]/H; 
plot3([marks, zeros(1,H+1); marks, ones(1,H+1)], ...
  [zeros(1,H+1), marks; ones(1,H+1), marks], ...
  zeros(2,2*H+2)+eps,'k')

% loop through b-splines
V=zeros(2*n+1);
V(n+1,n+1)=1;
[vXY,X,Y] = spline_2d(V,n+1,n,M);

h=surf(((n+1)*X-n)/H,((n+1)*Y-n)/H,U(1,1)*vXY,'FaceAlpha',0.9);
middle=floor((H+n)/2);

fprintf('\npress <return> to shift B-spline\n\n')
for k=1:middle
  pause
  delete(h);
  h=surf(((n+1)*X-n+k)/H,((n+1)*Y-n)/H,U(k+1,1)*vXY,'FaceAlpha',0.9);
end

for k=1:H+n-1
  pause
  delete(h);
  h=surf(((n+1)*X-n+middle)/H,((n+1)*Y-n+k)/H,U(middle+1,k+1)*vXY,'FaceAlpha',0.9);
end

for k=middle:H+n-1
  pause
  delete(h);
  h=surf(((n+1)*X-n+k)/H,((n+1)*Y+H-1)/H,U(k+1,H+n)*vXY,'FaceAlpha',0.9);
end

hold off
