function [U,wuXYZ,X,Y,Z,R,e] = elasticity_3d(E,nu,f,wD,w,H,n,PAR)
% [U,wuXYZ,X,Y,Z,R,e] = elasticity_3d(E,nu,f,wD,w,H,n,PAR)
%
% Ritz-Galerkin approximation of the Lame-Navier system
%   -div(sigma(u)) = f
% with weighted b-splines
%   u_m ~ sum_k U(k1,k2,k3,m) w(x,y,z) b_k(x,y,z) (m=1,2,3)
% on the domain D in (0,1)^3 with wD > 0
%
% E 
%   Young modulus
% nu
%   Poisson ratio
% function F = f(x,y,z)
%   internal force, column of values for each component
% function W = wD(x,y,z)
%   positive on domain D, subset of (0,1)^3
% function [W,Wx,Wy,Wz,Wxx,Wxy,Wxz,Wyy,Wyz,Wzz] = w(x,y,z)
%   models essential homogeneous boundary conditions
% H
%   number of cells per coordinate direction, width 1/H
% n 
%   degree of b-splines
% PAR
%   algorithmic parameters
% U(1:H+n,1:H+n,1:H+n,1:3)
%   coefficients of the weighted b-splines
% wuXYZ(1:H*M,1:H*M,1:H*M,1:3)
%  grid values of the weighted spline, M=PAR.values
% X(1:H*M,1:H*M,1:H*M), Y(1:H*M,1:H*M,1:H*M), Z(1:H*M,1:H*M,1:H*M)
%  uniform grid of (H*M)^3 points in (0,1)^3, M=PAR.values
% R(1:M*H,1:M*H,1:2)
%  residuum of the partial differential equation, M=PAR.values 
% e
%   relative error for the differential equation 
% -> see documentation for details 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

if PAR.info, fprintf('\nelasticity_3d\n'); end

% integration, assembly, solution, visualization, and error
int = integrate_3d(wD,H,PAR);
[G,F] = assemble_3de(E,nu,f,w,H,n,int,PAR);
U = solve_3de(G,F,PAR);
[wuXYZ,X,Y,Z,R,e] = evaluate_3de(E,nu,f,wD,w,U,H,n,PAR);
if PAR.info > 1, visualize_3de(wD,wuXYZ,X,Y,Z,H); end


