function example_bvp_2d_convergence
% convergence analysis for the Poisson problem 
%  -Delta u = f
% on the domain D: w>0 with Dirichlet boundary conditions 
% solution u = sin(w) -> f = -Delta sin(w)

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% maximal degree n and number of grid refinements
n_max = 4; H_steps = 5;

% functions describing domain, essential boundary, and pde
% (see also LOCAL FUNCTIONS as well as m-files w_shovel.m and p_poisson.m) 
w = @w_shovel; wD = w;
p = @p_poisson;
q = @(x,y) zeros(size(x));
f = @(x,y) f_delta_sinw(x,y,w);

% L2 and pde errors for different degrees and grid widths
fh = figure;
for n = 1:n_max
  for k = 1:H_steps+1
    H = 2^k;    
    PAR=set_par(H,n); PAR.info = 1; PAR.values = 3;
    [U,wuXY,X,Y,R,error_pde(k,n)] = bvp_2d(p,q,f,w,w,H,n,PAR);    
    uXY_exact = sin(w(X,Y)); uXY_exact(isnan(wuXY))=0;               
    error = uXY_exact(:) - wuXY(:); error(isnan(error)) = 0;
    error_L2(k,n) = norm(error(:))/norm(uXY_exact(:));    
  end
  rate_pde = -diff(log(error_pde))/log(2);
  rate_L2 = -diff(log(error_L2))/log(2);
  
  % visualization 
  close(fh); fh=figure; 
  set(fh,'units','normalized','position',[.35,.35,.6,.6]);

  subplot(2,3,6)
  plot(rate_pde,'linewidth',2);
  axis([1,5,0,4]);
  title('pde error rate')

  subplot(2,3,5)  
  plot(rate_L2,'linewidth',2);
  axis([1,5,1.5,5.5]);
  title('L2 error rate')

  subplot(2,3,3)
  semilogy(error_pde,'linewidth',2);
  axis([1,6,10^-6,10^-1]);
  title('pde error')

  subplot(2,3,2)
  semilogy(error_L2,'linewidth',2);
  axis([1,6,10^-10,1]);
  title('L2 error')
  legendnames{n}=sprintf('degree %d',n);
  legend(legendnames,'location','southwest')

  subplot(2,3,1)
  surf(X,Y,wuXY,'FaceAlpha',0.6)
  colormap winter, view(3), shading interp
  title('Solution')
   
  subplot(2,3,4)
  wDXY=w(X,Y);
  hold on
  contourf(X,Y,wDXY,[0 inf])
  hold off
  view(2)
  title('Domain')
  pause(1)
end 

%%%%% LOCAL FUNCTIONS
  
function F = f_delta_sinw(x,y,w)
% force f = -Delta u for solution u(x,y) = sin(w(x,y))
[W,Wx,Wy,Wxx,Wxy,Wyy] = w(x,y);
F = sin(W).*(Wx.^2+Wy.^2)-cos(W).*(Wxx+Wyy);

