function example_bvp_3d_convergence
% convergence (increasing degree, fixed grid width) for 
%  -Delta u + u = exp(x-2y+3z) 
% on a smooth domain with natural boundary conditions 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% grid and maximal degree
H = 4; n_max = 4;

% pde, domain, and natural boundary conditions
% (see also m-files p_poisson.m, w_exp_3d.m, and w_one.m)
p  = @p_poisson; 
q  = @(x,y,z) ones(size(x));
f  = @(x,y,z) exp(x-2*y+3*z);
wD = @w_exp_3d; 
w  = @w_one;

% relative L2 error for different degrees
for n=1:n_max 
  PAR=set_par(H,n); PAR.values = 5; PAR.info = 1;
  [U,u_H,X,Y,Z] = bvp_3d(p,q,f,wD,w,H,n,PAR);
  u_H(isnan(u_H)) = 0;
  % estimate error via difference of consecutive solutions
  if n>1
    e = u_H-u_old;
    error(n-1) = norm(e(:))/norm(u_old(:));
  end
  u_old = u_H;
end

% domain 
figure 
p = patch(isosurface(X,Y,Z,wD(X,Y,Z),0),'EdgeColor','none','FaceColor','blue');

% print results
fprintf('\ndegree       L2 error\n');
for n=1:n_max-1
  fprintf('    %2d%15.5e\n',n,error(n));
end

