function example_bvp_3d_csg
% Poisson's equation for a domain constructed with Boolean operations 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% grid width and degree
H = 8; n = 1;

% pde (see also m-file p_poisson.m)
p  = @p_poisson; 
q  = @(x,y,z) zeros(size(x));
f  = @(x,y,z) ones(size(x));

% finite element approximation
PAR = set_par(H,n); PAR.steps = 0;
bvp_3d(p,q,f,@w_csg,@w_csg,H,n,PAR);


%%%%% LOCAL FUNCTIONS
% domain 
function [W,Wx,Wy,Wz,Wxx,Wxy,Wxz,Wyy,Wyz,Wzz] = w_csg(x,y,z)
% combining elementary weight functions via Rvachev's method

% ball 
W1 = 4/25-(x-1/2).^2-(y-1/2).^2-(z-1/2).^2; 
W1x = -2*(x-1/2); W1y = -2*(y-1/2); W1z = -2*(z-1/2); 

% half space
W2 = z-1/2; 
W2x = zeros(size(x)); W2y = W2x; W2z = ones(size(z)); 

% ellipsoid
W3 = 1-16*(x-1/2).^2-16*(y-1/2).^2-25/4*(z-1/2).^2;
W3x = -32*(x-1/2); W3y = -32*(y-1/2); W3z = -25/2*(z-1/2);

% intersection of ball with half space
s = sqrt(W1.^2+W2.^2);
W = W1+W2-s;
Wx = W1x+W2x-(W1.*W1x+W2.*W2x)./s;
Wy = W1y+W2y-(W1.*W1y+W2.*W2y)./s;
Wz = W1z+W2z-(W1.*W1z+W2.*W2z)./s;

% union with ellipsoid
s = sqrt(W.^2+W3.^2);
W = W+W3+s;
Wx = Wx+W3x+(W.*Wx+W3.*W3x)./s;
Wy = Wy+W3y+(W.*Wy+W3.*W3y)./s;
Wz = Wz+W3z+(W.*Wz+W3.*W3z)./s;

% leave second derivatives undefined
Wxx = NaN*W; Wxy = Wxx; Wxz = Wxx; Wyy = Wxx; Wyz = Wxx; Wzz = Wxx;

