function example_elasticity_2d_disc
% displacement of an excentric rotating steel disc

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% offset and inner radius
d = 0.06; r = 0.1;

% degree and refinement steps
n = 4; H_steps = 3;

% Young modulus (normalized), Poisson ratio, and force
% (see m-file f_centrifugal.m)
E  = 1; nu = 0.28;
f  = @(x,y) f_centrifugal(x-1/2+d,y-1/2);

% domain and essential boundary
% (see m-file w_disc)
wD = @(x,y) -w_disc(x-1/2,y-1/2,1/2).*w_disc(x-1/2+d,y-1/2,r);
w  = @(x,y) w_disc(x-1/2+d,y-1/2,r);

% finite element approximations with different grid widths
figure 
for k=1:H_steps+1
  H(k) = 4*2^k; PAR = set_par(H(k),n);
  [U,wuXY,X,Y,R,e(k)] = elasticity_2d('stress',E,nu,f,wD,w,H(k),n,PAR);
pause(1)
end

% error for the pde and estimated convergence rate
r = [NaN -diff(log(e))/log(2)];
fprintf('\n  H      pde error           rate\n');
for k=1:H_steps+1
  fprintf('%3d%15.3e%15.3e\n',H(k),e(k),r(k));
end

