function example_elasticity_2d_tunnel
% displacement of a tunnel-shaped concrete structure under gravity 
% (singular solution -> low accuracy)

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% degree, refinement steps
n = 1; H_steps = 3;

% Young modulus (normalized) and Poisson ratio
E = 1; nu = 0.2;

% force, domain, and essential boundary 
% (see m-files f_gravity.m, wD_tunnel.m, and w_line.m)
f = @f_gravity;
wD = @wD_tunnel; w = @w_line;

% finite element approximations with different grid widths
figure
for k=1:H_steps+1;
  H{k} = 2*2^k; 
  PAR=set_par(H{k},n);
  [U,wuXY{k},X,Y] = elasticity_2d('strain',E,nu,f,wD,w,H{k},n,PAR); 
  wuXY{k}(isnan(wuXY{k}))=0; 
  pause(1)
end

% estimated L2 error 
fprintf('\n  H       L2 error\n');
for k=1:H_steps
  error = norm(wuXY{k+1}(:)-wuXY{k}(:))./norm(wuXY{k+1}(:));
  fprintf('%3d%15.5e\n',H{k},error);
end

