function parameters_2d(n_max)
% function parameters_2d(n_max)
% parameters for Gauss formulas, grids, and interpolation 
%  
% n_max
%   maximal degree
% -> generates a file parameters_2d.mat 
% with structure cell arrays GAUSS, PTS, POL 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% Gauss parameters for [0,1]
for n=1:n_max
  [GAUSS{n}.C,GAUSS{n}.P] = gausspar(n);
end

% Gauss parameters for [0,1]^2
for n=1:n_max
  for kx=1:n, for ky=1:n
    cxy(kx,ky) = GAUSS{n}.C(kx)*GAUSS{n}.C(ky);
    px(kx,ky) = GAUSS{n}.P(kx);
    py(kx,ky) = GAUSS{n}.P(ky);
  end, end  
  GAUSS2{n}.C = cxy(:); GAUSS2{n}.P = [px(:), py(:)];
end

% centered interpolation points in [-1/2, 1/2] and [0,1]^2
for n=1:n_max
  x{n} = [1/2:n]'/n-1/2;
  [PTS{n}.X,PTS{n}.Y] = ndgrid(x{n}+1/2);
  PTS{n}.X = PTS{n}.X(:); PTS{n}.Y = PTS{n}.Y(:); 
end

% condensed inverses of Vandermonde matrices
for n=1:n_max
  % interpolation on [-1/2,1/2]
  POL{n}.V = vanderinv(n);  
  % interpolation on [-1/2,1/2]^2
  for k1=1:n, for k2=1:n, for k3=1:n, for k4=1:n
    POL{n}.V2(k1,k2,k3,k4) = POL{n}.V(k1,k3)*POL{n}.V(k2,k4);
  end, end, end, end
  POL{n}.V2 = reshape(POL{n}.V2,n^2,n^2);
end

% matrices for computing edge polynomials
for n=1:n_max
  POL{n}.VE =[(-1/2).^[0:n-1]; (1/2).^[0:n-1]];
end

% extremal vector (1/2)^(kx+ky)
for n=1:n_max
  [kx,ky] = ndgrid([0:n-1]);
  POL{n}.E = 2.^(-kx(:)-ky(:)); 
end

if exist('parameters_2d.mat','file')
  delete parameters_2d.mat;
end
save parameters_2d GAUSS* PTS* POL*

