function parameters_3d(n_max)
% function parameters_3d(n_max)
% parameters for Gauss formulas, grids, and interpolation 
%  
% n_max
%   maximal degree
% -> generates a file parameters_3d.mat 
% with structure cell arrays GAUSS, PTS, POL 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% Gauss parameters for [0,1]
for n=1:n_max
  [GAUSS{n}.C,GAUSS{n}.P] = gausspar(n);
end

% Gauss parameters for [0,1]^3
for n=1:n_max
  for kx=1:n, for ky=1:n, for kz=1:n
  cxyz(kx,ky,kz) = GAUSS{n}.C(kx)*GAUSS{n}.C(ky)*GAUSS{n}.C(kz);
  px(kx,ky,kz) = GAUSS{n}.P(kx);
  py(kx,ky,kz) = GAUSS{n}.P(ky);
  pz(kx,ky,kz) = GAUSS{n}.P(kz);
  end, end, end  
  GAUSS3{n}.C = cxyz(:); GAUSS3{n}.P = [px(:), py(:), pz(:)];
end

% centered interpolation points in [-1/2,1/2] and [0,1]^3
for n=1:n_max
  x{n} = [1/2:n]'/n-1/2;
  [PTS{n}.X,PTS{n}.Y,PTS{n}.Z] = ndgrid(x{n}+1/2);
  PTS{n}.X = PTS{n}.X(:); 
  PTS{n}.Y = PTS{n}.Y(:); 
  PTS{n}.Z = PTS{n}.Z(:); 
end

% condensed inverses of Vandermonde matrix 
for n=1:n_max
  % interpolation on [-1/2,1/2]
  POL{n}.V = vanderinv(n);
  % interpolation on [-1/2,1/2]^3
  for k1=1:n, for k2=1:n, for k3=1:n, for k4=1:n, for k5=1:n, for k6=1:n
    POL{n}.V3(k1,k2,k3,k4,k5,k6) = POL{n}.V(k1,k4)*POL{n}.V(k2,k5)*POL{n}.V(k3,k6);
  end, end, end, end, end, end
  POL{n}.V3 = reshape(POL{n}.V3,n^3,n^3);
end

% matrices for computing edge polynomials
for n=1:n_max 
  POL{n}.VE =[(-1/2).^[0:n-1]; (1/2).^[0:n-1]];
  for k1=1:2, for k2=1:2, for k3=1:n, for k4=1:n
    POL{n}.VE2(k1,k2,k3,k4) = POL{n}.VE(k1,k3)*POL{n}.VE(k2,k4);
  end, end, end, end
  POL{n}.VE2 = reshape(POL{n}.VE2,4,n^2);
end

% extremal vector (1/2)^(kx+ky+kz)
for n=1:n_max
  [kx,ky,kz] = ndgrid([0:n-1]);
  POL{n}.E = 2.^(-kx(:)-ky(:)-kz(:)); 
end

if exist('parameters_3d.mat','file')
  delete parameters_3d.mat;
end
save parameters_3d GAUSS* PTS* POL*

