function [uXY,X,Y] = spline_2d(U,H,n,M)
% [uXY,X,Y] = spline_2d(U,H,n,M)
% values of a spline on a regular grid in (0,1)^2
%
% U(H+n,H+n)
%  scalar or vector coefficients of the b-splines
% H
%  number of cells per coordinate direction, width 1/H
% n or (n1,n2) 
%  degree of the b-splines
% M
%   number of evaluation points per cell edge
% X(H*M,H*M), Y(H*M,H*M)
%  uniform grid of (H*M)^2 points in (0,1)^2
% uXY(H*M,H*M)
%   grid values of the spline
% -> see documentation for details 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

if (nargin<4), demo_spline_2d; return; end

% b-spline values
if length(n) == 1, n = [n, n]; end
bx = b_spline([1/2:M]'/M,n(1)); bx = bx(:);
by = b_spline([1/2:M]'/M,n(2)); by = by(:);

% define grid
[X,Y] = ndgrid([1/2:M*H]/(M*H));

% evaluate spline
uXY = zeros((H+2*n(1))*M,(H+2*n(2))*M,size(U,3));
indx = [0:H+n(1)-1]*M; indy = [0:H+n(2)-1]*M;
for mx=1:M*(n(1)+1), for my=1:M*(n(2)+1)
  uXY(mx+indx,my+indy,:) = ... 
    uXY(mx+indx,my+indy,:) + bx(mx)*by(my)*U; 
end, end
uXY = uXY(n(1)*M+1:end-n(1)*M,n(2)*M+1:end-n(2)*M,:);

