function [uXYZ,X,Y,Z] = spline_3d(U,H,n,M)
% [uXYZ,X,Y,Z] = spline_3d(U,H,n,M)
% values of a spline on a regular grid in (0,1)^3
%
% U(H+n,H+n,H+n)
%  scalar or vector coefficients of the weighted b-splines
% H
%  number of cells per coordinate direction, width 1/H
% n or (n1,n2,n3) 
%  degree of the b-splines
% M
%   number of evaluation points per cell edge
% X(H*M,H*M,H*M), Y(H*M,H*M,H*M),  Z(H*M,H*M,H*M)
%  uniform grid of (H*M)^3 points in (0,1)^3
% UXYZ(H*M,H*M,H*M)
%   grid values of the spline
% -> see documentation for details 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

if nargin<4; demo_spline_3d; return; end

% b-spline values
if length(n) == 1, n = [n, n, n]; end
bx = b_spline([1/2:M]'/M,n(1)); bx = bx(:);
by = b_spline([1/2:M]'/M,n(2)); by = by(:);
bz = b_spline([1/2:M]'/M,n(3)); bz = bz(:);

% define grid
[X,Y,Z] = ndgrid([1/2:M*H]/(M*H));

% evaluate spline
uXYZ = zeros((H+2*n(1))*M,(H+2*n(2))*M,(H+2*n(3))*M,size(U,4));
indx = [0:H+n(1)-1]*M; 
indy = [0:H+n(2)-1]*M;
indz = [0:H+n(3)-1]*M; 

for mx=1:M*(n(1)+1), for my=1:M*(n(2)+1), for mz=1:M*(n(3)+1)
  uXYZ(mx+indx,my+indy,mz+indz,:) = ...
    uXYZ(mx+indx,my+indy,mz+indz,:)+bx(mx)*by(my)*bz(mz)*U; 
end, end, end
uXYZ = uXYZ(n(1)*M+1:end-n(1)*M, ... 
  n(2)*M+1:end-n(2)*M,n(3)*M+1:end-n(3)*M,:);

