function visualize_2de(wD,wuXY,X,Y,H)
% visualize_2de(wD,wuXY,X,Y,H)
% displacement sum (u_k,1,u_k,2) (w b_k) on wD > 0
%
% function W = wD(x,y)
%   positive on the domain D, subset of (0,1)^2
% wuXY(1:H*M,1:H*M,1:2)
%   grid values of the weighted spline
% X(1:H*M,1:H*M), Y(1:H*M,1:H*M)
%   uniform grid of (H*M)^2 points in (0,1)^2
% H
%   number of cells per coordinate direction, width 1/H
% -> see documentation for details 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% plot solution
clf, hold on
title('domain as well as direction and size (colored) of displacement')

% displacement 
dXY = sqrt(wuXY(:,:,1).^2+wuXY(:,:,2).^2);
surf(X,Y,0*dXY,dXY,'FaceAlpha',0.5)
colorbar 

M=size(X,1)/H;
[Xm,Ym] = ndgrid([1/2:H]/H);

if 2*fix(M/2) ~= M
  % M odd
  ind = [(M+1)/2:M:M*H];
  wUm = wuXY(ind,ind,:);
else 
  % M even, value at midpoint as average
  wUm = zeros(H,H,2);
  ind = [M/2:M:M*H];
  for m1=0:1, for m2=0:1
    wUm = wUm + wuXY(m1+ind,m2+ind,:);
  end, end
  wUm = wUm/4;
end

quiver(Xm,Ym,wUm(:,:,1),wUm(:,:,2),1,'k')
shading interp
axis([0 1 0 1])

% grid
marks = [0:H]/H; 
x = [marks, zeros(1,H+1); marks, ones(1,H+1)];
y = [zeros(1,H+1), marks; ones(1,H+1), marks];
z = zeros(2,2*H+2);
plot3(x,y,z,'k')

hold off

