function visualize_3de(wD,wuXYZ,X,Y,Z,H)
% visualize_3de(wD,wuXYZ,X,Y,Z,H)
% displacement sum_k U(k1,k2,k3,1:3) (w b_k) on wD > 0
%
% function W = wD(x,y,z)
%   positive on domain D, subset of (0,1)^3
% wuXYZ(1:H*M,1:H*M,1:H*M,1:3)
%   grid values of weighted spline
% X(1:H*M,1:H*M,1:H*M), Y(1:H*M,1:H*M,1:H*M), Z(1:H*M,1:H*M,1:H*M)
%   uniform grid of (H*M)^3, points in (0,1)^3
% H
%   number of cells per coordinate direction, width 1/H
% -> see documentation for details 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% plot solution
clf, hold on
title('domain and displacement')

% domain
W=wD(X,Y,Z);
p = patch(isosurface(X,Y,Z,W,0));
set(p,'FaceAlpha',0.2,'EdgeColor','none','FaceColor','red')
axis([0 1 0 1 0 1]), box on, view(3) 

% displacement at cell midpoints
M=size(X,1)/H;
[Xm,Ym,Zm] = ndgrid([1/2:H]/H);
if 2*fix(M/2) ~= M
  % M odd
  ind = [(M+1)/2:M:M*H];
  wUm = wuXYZ(ind,ind,ind,:);
else 
  % M even, value at midpoint as average
  wUm = zeros(H,H,H,3);
  ind = [M/2:M:M*H];
  for m1=0:1, for m2=0:1, for m3=0:1
    wUm = wUm + wuXYZ(m1+ind,m2+ind,m3+ind,:);
  end, end, end
  wUm = wUm/8;
end
quiver3(Xm,Ym,Zm,wUm(:,:,:,1),wUm(:,:,:,2),wUm(:,:,:,3),1,'k')
hold off

