function [W,Wx,Wy,Wxx,Wxy,Wyy] = w_bezier(x,y)
% w_bezier(x,y): polynomial weight function in Bezier form
% degree (n,n) with coefficients C{1:n+1,1:n+1}

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% Bezier coefficients
C = {-1 0 -8 0 -1; 0 16 -10 16 0; -8 -10 4 -10 -8; 0 16 -10 16 0; -1 0 -8 0 -1};
n = size(C,1)-1;

% evaluation weights
p00 = (1-x).*(1-y); p01 = (1-x).*y; p10 = x.*(1-y); p11 = x.*y;

% de Casteljau algorithm
for k=0:n-2
  for kx=1:n-k, for ky=1:n-k 
    C{kx,ky} = p00.*C{kx,ky} + p01.*C{kx,ky+1} + p10.*C{kx+1,ky} + p11.*C{kx+1,ky+1};
  end, end
end
Wx = n*((1-y).*(C{2,1}-C{1,1}) + y.*(C{2,2}-C{1,2}));
Wy = n*((1-x).*(C{1,2}-C{1,1}) + x.*(C{2,2}-C{2,1}));
W = p00.*C{1,1}+p01.*C{1,2}+p10.*C{2,1}+p11.*C{2,2};

% leave second derivatives undefined
Wxx = NaN*W; Wxy = NaN*W; Wyy = NaN*W;

