function [W,Wx,Wy,Wxx,Wxy,Wyy] = w_product(x,y)
% w_product(x,y): weight function defined as product
% factors: elementary weight functions with non-intersecting zero sets

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% disc with circular holes, centers c and radii r 
c = [2 3; 4 4; 4 2; 3 3]/6; r = [1; 2; 3; 10]/20;

% evaluate weight functions
for k=1:size(c,1)
  D{k} = r(k)^2-(x-c(k,1)).^2-(y-c(k,2)).^2;
  Dx{k} = 2*(c(k,1)-x); 
  Dy{k} = 2*(c(k,2)-y);
end

% initilaize with 1 and multiply with (-1) for every hole
W = (-1)^(size(c,1)-1)*ones(size(x)); Wx = zeros(size(x)); Wy = Wx; 
% multiply
for k=1:size(c,1)
  Wx = Wx.*D{k} + W.*Dx{k};
  Wy = Wy.*D{k} + W.*Dy{k};
  W = W.*D{k};
end

% leave second derivatives undefined
Wxx = NaN*W; Wxy = NaN*W; Wyy = NaN*W;

