function [W,Wx,Wy,Wxx,Wxy,Wyy] = w_rvachev(x,y)
% w_rvachev(x,y): weight function via Rvachev's method
% combines elementary weight functions 

% FEMB-Programs (Version: 1.0)
% test version: for educational use and illustration purposes only
% -> see documentation for details

% parabolic region
W1 = x-1/4+(y-1/2).^2; 
W1x = ones(size(x)); W1y = 2*y-1; 

% ellipse
W2 = 1-x.^2-4*(y-1/2).^2; 
W2x = -2*x; W2y = 4-8*y; 

% disc
W3 = 1/25-(x-1/2).^2-(y-1/2).^2;
W3x = 1-2*x; W3y = 1-2*y; 

% intersection of parabolic region with ellipse
s = sqrt(W1.^2+W2.^2);
W = W1+W2-s;
Wx = W1x+W2x-(W1.*W1x+W2.*W2x)./s; Wy = W1y+W2y-(W1.*W1y+W2.*W2y)./s;

% subtraction of disc
s = sqrt(W.^2+W3.^2);
W = W-W3-s;
Wx = Wx-W3x-(W.*Wx+W3.*W3x)./s; Wy = Wy-W3y-(W.*Wy+W3.*W3y)./s;

% leave second derivatives undefined
Wxx = NaN*W; Wxy = NaN*W; Wyy = NaN*W;

